@@ -50,6 +50,9 @@ INTERNALERROR_LOCKERROR = 'InternalError.LockError'
 # 通信协议错误。
 INTERNALERROR_PROTOCOLERROR = 'InternalError.ProtocolError'
 
+# 内部错误。
+INTERNALERROR_UNDEFINEDERROR = 'InternalError.UndefinedError'
+
 # 未知的内部错误。
 INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'
 
@@ -71,6 +74,9 @@ LIMITEXCEEDED_MAXUNUSEDJOBS = 'LimitExceeded.MaxUnusedJobs'
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 当前操作不满足条件被阻止。
+OPERATIONDENIED_BIZOPERATIONDENIEDERROR = 'OperationDenied.BizOperationDeniedError'
+
 # 任务操作失败。
 OPERATIONDENIED_JOBOPERATIONDENIEDERROR = 'OperationDenied.JobOperationDeniedError'
 
